@@ -8,6 +8,8 @@ __all__ = [
     "CanonMapMySQLConfig",
     "CanonMapMySQLClient",
     "EntityMappingRequest",
+    "EntityMappingResponse",
+    "SingleMappedEntity",
     "TableField",
     "FieldTransformType",
 ]
\ No newline at end of file
