@@ -123,7 +123,7 @@ class MatcherManager:
         candidates = candidates.union(initialism_candidates)
         candidates = candidates.union(exact_candidates)
         
-        logger.debug(f"TableField {field.field_name}: phonetic={len(phonetic_candidates)}, soundex={len(soundex_candidates)}, initialism={len(initialism_candidates)}, exact={len(exact_candidates)}")
+        logger.debug(f"TableField {request.select_field.field_name}: phonetic={len(phonetic_candidates)}, soundex={len(soundex_candidates)}, initialism={len(initialism_candidates)}, exact={len(exact_candidates)}")
         
         logger.debug(f"Total candidates found: {len(candidates)}")
         
@@ -166,10 +166,9 @@ class MatcherManager:
                 
                 return additional_candidates
             
-            for field in request.select_fields:
-                additional = _get_more_candidates(conn, normalized_entity_name, field.table_name, field.field_name, min_candidates - len(candidates))
-                candidates = candidates.union(additional)
-                logger.debug(f"Added {len(additional)} additional candidates from broader search")
+            additional = _get_more_candidates(conn, normalized_entity_name, request.select_field.table_name, request.select_field.field_name, min_candidates - len(candidates))
+            candidates = candidates.union(additional)
+            logger.debug(f"Added {len(additional)} additional candidates from broader search")
         
         logger.debug(f"Final total candidates: {len(candidates)}")
 
@@ -239,11 +238,11 @@ class MatcherManager:
         # Return top_n results
         return EntityMappingResponse(results=[
             SingleMappedEntity(
-                raw_entity=name, 
-                canonical_entity=name, 
-                canonical_table_name=field.table_name, 
-                canonical_field_name=field.field_name, 
+                raw_entity=request.entity_name, 
+                canonical_entity=candidate_name, 
+                canonical_table_name=request.select_field.table_name, 
+                canonical_field_name=request.select_field.field_name, 
                 score=score) 
-            for name, score in ranked[:request.top_n]
-            for field in request.select_fields])
+            for candidate_name, score in ranked[:request.top_n]
+        ])
     
